# -*- coding: utf-8 -*-

"""Top-level package for sknlp-tf."""

__author__ = """nanaya tachibana"""
__email__ = "nanaya100@gmail.com"
__version__ = "0.3.1"
